Index: src/Fragmentation/Summation/SetValues/unittests/SamplingGridPropertiesUnitTest.cpp
===================================================================
--- src/Fragmentation/Summation/SetValues/unittests/SamplingGridPropertiesUnitTest.cpp	(revision 5b1e5e3171f6df6d1ae7f2ebc67e13bbf15c764b)
+++ src/Fragmentation/Summation/SetValues/unittests/SamplingGridPropertiesUnitTest.cpp	(revision cb30d9d8a96f55de0036183d6a0a15f689be8606)
@@ -75,7 +75,7 @@
 }
 
-/** UnitTest for isCompatible()
+/** UnitTest for isEquivalent()
  */
-void SamplingGridPropertiesTest::isCompatible_Test()
+void SamplingGridPropertiesTest::isEquivalent_Test()
 {
   const double begin[3] = { 0., 0., 0. };
@@ -91,13 +91,40 @@
 
   // only checks for same level
+  CPPUNIT_ASSERT( props->isEquivalent(*props) );
+  CPPUNIT_ASSERT( props->isEquivalent(sameprops) );
+  CPPUNIT_ASSERT( sameprops.isEquivalent(*props) );
+  CPPUNIT_ASSERT( !props->isEquivalent(otherprops) );
+  CPPUNIT_ASSERT( !otherprops.isEquivalent(*props) );
+  CPPUNIT_ASSERT( !props->isEquivalent(anotherprops) );
+  CPPUNIT_ASSERT( !anotherprops.isEquivalent(*props) );
+  CPPUNIT_ASSERT( !props->isEquivalent(moreotherprops) );
+  CPPUNIT_ASSERT( !moreotherprops.isEquivalent(*props) );
+}
+
+/** UnitTest for isCompatible()
+ */
+void SamplingGridPropertiesTest::isCompatible_Test()
+{
+  const double begin[3] = { 0., 0., 0. };
+  const double otherbegin[3] = { .5, .5, .5 };
+  const double end[3] = { 1., 1., 1. };
+  const double otherend[3] = { 2., 2., 2. };
+
+  // create other props
+  SamplingGridProperties sameprops(begin, end, 2); // same
+  SamplingGridProperties secondhalf(otherbegin, end, 2); // second half
+  SamplingGridProperties goingbeyond(begin, otherend, 2); // going beyond
+  SamplingGridProperties finerlevel(begin, end, 4); // same but different level
+
+  // only checks for same level
   CPPUNIT_ASSERT( props->isCompatible(*props) );
   CPPUNIT_ASSERT( props->isCompatible(sameprops) );
   CPPUNIT_ASSERT( sameprops.isCompatible(*props) );
-  CPPUNIT_ASSERT( props->isCompatible(otherprops) );
-  CPPUNIT_ASSERT( otherprops.isCompatible(*props) );
-  CPPUNIT_ASSERT( props->isCompatible(anotherprops) );
-  CPPUNIT_ASSERT( anotherprops.isCompatible(*props) );
-  CPPUNIT_ASSERT( !props->isCompatible(moreotherprops) );
-  CPPUNIT_ASSERT( !moreotherprops.isCompatible(*props) );
+  CPPUNIT_ASSERT( props->isCompatible(secondhalf) );
+  CPPUNIT_ASSERT( !secondhalf.isCompatible(*props) );
+  CPPUNIT_ASSERT( !props->isCompatible(goingbeyond) );
+  CPPUNIT_ASSERT( goingbeyond.isCompatible(*props) );
+  CPPUNIT_ASSERT( props->isCompatible(finerlevel) );
+  CPPUNIT_ASSERT( !finerlevel.isCompatible(*props) );
 }
 
Index: src/Fragmentation/Summation/SetValues/unittests/SamplingGridPropertiesUnitTest.hpp
===================================================================
--- src/Fragmentation/Summation/SetValues/unittests/SamplingGridPropertiesUnitTest.hpp	(revision 5b1e5e3171f6df6d1ae7f2ebc67e13bbf15c764b)
+++ src/Fragmentation/Summation/SetValues/unittests/SamplingGridPropertiesUnitTest.hpp	(revision cb30d9d8a96f55de0036183d6a0a15f689be8606)
@@ -24,4 +24,5 @@
 {
     CPPUNIT_TEST_SUITE( SamplingGridPropertiesTest) ;
+    CPPUNIT_TEST ( isEquivalent_Test );
     CPPUNIT_TEST ( isCompatible_Test );
     CPPUNIT_TEST ( equality_Test );
@@ -32,4 +33,5 @@
       void setUp();
       void tearDown();
+      void isEquivalent_Test();
       void isCompatible_Test();
       void equality_Test();
Index: src/Fragmentation/Summation/SetValues/unittests/SamplingGridUnitTest.hpp
===================================================================
--- src/Fragmentation/Summation/SetValues/unittests/SamplingGridUnitTest.hpp	(revision 5b1e5e3171f6df6d1ae7f2ebc67e13bbf15c764b)
+++ src/Fragmentation/Summation/SetValues/unittests/SamplingGridUnitTest.hpp	(revision cb30d9d8a96f55de0036183d6a0a15f689be8606)
@@ -24,4 +24,5 @@
 {
     CPPUNIT_TEST_SUITE( SamplingGridTest) ;
+    CPPUNIT_TEST ( equivalentGrids_Test );
     CPPUNIT_TEST ( compatibleGrids_Test );
     CPPUNIT_TEST ( operatorPlusEqual_Test );
@@ -42,4 +43,5 @@
       void setUp();
       void tearDown();
+      void equivalentGrids_Test();
       void compatibleGrids_Test();
       void isCongruent_Test();

Index: src/Fragmentation/Summation/SetValues/unittests/SamplingGridUnitTest.cpp
===================================================================
--- src/Fragmentation/Summation/SetValues/unittests/SamplingGridUnitTest.cpp	(revision 5b1e5e3171f6df6d1ae7f2ebc67e13bbf15c764b)
+++ src/Fragmentation/Summation/SetValues/unittests/SamplingGridUnitTest.cpp	(revision cb30d9d8a96f55de0036183d6a0a15f689be8606)
@@ -89,13 +89,46 @@
 }
 
-/** UnitTest on compatible combination of props and values
- */
-void SamplingGridTest::compatibleGrids_Test()
+/** UnitTest on equivalent combination of props and values
+ */
+void SamplingGridTest::equivalentGrids_Test()
 {
   // check illegal grid
   const double begin[NDIM] = { 0., 0., 0. };
-  const double end[NDIM] = { 2., 2., 2. };
+  const double end[NDIM] = { 1., 1., 1. };
   SamplingGridProperties illegal_props(begin, end, 5);
   SamplingGridProperties legal_props(begin, end, 2);
+  CPPUNIT_ASSERT( !grid->isEquivalent(illegal_props) );
+  CPPUNIT_ASSERT( grid->isEquivalent(legal_props) );
+  SamplingGrid::sampledvalues_t illegal_values;
+  for (size_t i=0; i< NUMBEROFSAMPLES(1); ++i)
+    illegal_values += 1.5;
+  SamplingGrid::sampledvalues_t legal_values;
+  for (size_t i=0; i< NUMBEROFSAMPLES(2); ++i)
+    legal_values += 1.5;
+#ifndef NDEBUG
+  // throws because props and size of illegal_values don't match
+  std::cout << "The following assertion is intended and does not indicate a failure of the test." << std::endl;
+  CPPUNIT_ASSERT_THROW( SamplingGrid illegal_grid(illegal_props, illegal_values), Assert::AssertionFailure );
+  std::cout << "The following assertion is intended and does not indicate a failure of the test." << std::endl;
+  CPPUNIT_ASSERT_THROW( SamplingGrid illegal_grid(legal_props, illegal_values), Assert::AssertionFailure );
+  std::cout << "The following assertion is intended and does not indicate a failure of the test." << std::endl;
+  CPPUNIT_ASSERT_THROW( SamplingGrid illegal_grid(illegal_props, legal_values), Assert::AssertionFailure );
+#endif
+  // check that grid is still the same
+  for (SamplingGrid::sampledvalues_t::const_iterator iter = grid->sampled_grid.begin();
+      iter != grid->sampled_grid.end(); ++iter)
+    CPPUNIT_ASSERT_EQUAL( grid_value, *iter );
+}
+
+/** UnitTest on compatible combination of props and values
+ */
+void SamplingGridTest::compatibleGrids_Test()
+{
+  // check illegal grid
+  const double begin[NDIM] = { 0., 0., 0. };
+  const double end[NDIM] = { 1., 1., 1. };
+  const double otherend[NDIM] = { 2.5, 2.5, 2.5 };
+  SamplingGridProperties illegal_props(begin, otherend, 5);
+  SamplingGridProperties legal_props(begin, end, 3);
   CPPUNIT_ASSERT( !grid->isCompatible(illegal_props) );
   CPPUNIT_ASSERT( grid->isCompatible(legal_props) );
@@ -143,8 +176,8 @@
   SamplingGrid default_grid(legal_props);
   // note that we always construct a temporary SamplingGrid from given props
-  CPPUNIT_ASSERT( default_grid.isCompatible(illegal_begin_props) == default_grid.isCongruent(illegal_begin_props));
-  CPPUNIT_ASSERT( default_grid.isCompatible(illegal_end_props) == default_grid.isCongruent(illegal_end_props));
-  CPPUNIT_ASSERT( default_grid.isCompatible(illegal_level_props) == default_grid.isCongruent(illegal_level_props));
-  CPPUNIT_ASSERT( default_grid.isCompatible(legal_props) == default_grid.isCongruent(legal_props) );
+  CPPUNIT_ASSERT( default_grid.isEquivalent(illegal_begin_props) == default_grid.isCongruent(illegal_begin_props));
+  CPPUNIT_ASSERT( default_grid.isEquivalent(illegal_end_props) == default_grid.isCongruent(illegal_end_props));
+  CPPUNIT_ASSERT( default_grid.isEquivalent(illegal_level_props) == default_grid.isCongruent(illegal_level_props));
+  CPPUNIT_ASSERT( default_grid.isEquivalent(legal_props) == default_grid.isCongruent(legal_props) );
 
   default_grid.setWindowSize(begin, end);